@@ -28,6 +28,7 @@
 
 #include "totem-python-plugin.h"
 #include "totem-plugin.h"
+#include "debug.h"
 
 #include <pygobject.h>
 #include <string.h>
@@ -39,8 +40,11 @@ call_python_method (TotemPythonObject *object,
 		    TotemObject       *totem,
 		    gchar             *method)
 {
+	PyGILState_STATE state;
 	PyObject *py_ret = NULL;
 
+	state = pyg_gil_state_ensure();
+
 	g_return_val_if_fail (PyObject_HasAttrString (object->instance, method), NULL);
 
 	if (totem == NULL) {
@@ -57,6 +61,8 @@ call_python_method (TotemPythonObject *object,
 	if (!py_ret)
 		PyErr_Print ();
 
+	pyg_gil_state_release (state);
+
 	return py_ret;
 }
 
@@ -64,6 +70,10 @@ static gboolean
 check_py_object_is_gtk_widget (PyObject *py_obj)
 {
 	static PyTypeObject *_PyGtkWidget_Type = NULL;
+	PyGILState_STATE state;
+	gboolean res = FALSE;
+
+	state = pyg_gil_state_ensure();
 
 	if (_PyGtkWidget_Type == NULL) {
 		PyObject *module;
@@ -76,12 +86,16 @@ check_py_object_is_gtk_widget (PyObject *py_obj)
 		if (_PyGtkWidget_Type == NULL) {
 			PyErr_SetString(PyExc_TypeError, "could not find python gtk widget type");
 			PyErr_Print();
-
-			return FALSE;
+			res = FALSE;
+			goto done;
 		}
 	}
 
-	return PyObject_TypeCheck (py_obj, _PyGtkWidget_Type) ? TRUE : FALSE;
+	res = PyObject_TypeCheck (py_obj, _PyGtkWidget_Type) ? TRUE : FALSE;
+
+done:
+	pyg_gil_state_release (state);
+	return res;
 }
 
 static void
@@ -180,20 +194,25 @@ static void
 totem_python_object_init (TotemPythonObject *object)
 {
 	TotemPythonObjectClass *class;
+	PyGILState_STATE state;
 
-	g_debug ("Creating Python plugin instance");
+	state = pyg_gil_state_ensure();
+
+	D("Creating Python plugin instance");
 
 	class = (TotemPythonObjectClass*) (((GTypeInstance*) object)->g_class);
 
 	object->instance = PyObject_CallObject (class->type, NULL);
 	if (object->instance == NULL)
 		PyErr_Print();
+
+	pyg_gil_state_release (state);
 }
 
 static void
 totem_python_object_finalize (GObject *object)
 {
-	g_debug ("Finalizing Python plugin instance");
+	D("Finalizing Python plugin instance");
 
 	if (((TotemPythonObject *) object)->instance) {
 		Py_DECREF (((TotemPythonObject *) object)->instance);
@@ -240,12 +259,16 @@ totem_python_object_get_type (GTypeModule *module,
 		(GInstanceInitFunc) totem_python_object_init
 	};
 
+	/* no need for pyg_gil_state_ensure() here since this function is only
+	 * used from within totem_python_module_load() where this is already
+	 * done */
+
 	Py_INCREF (type);
 
 	type_name = g_strdup_printf ("%s+TotemPythonPlugin",
 				     PyString_AsString (PyObject_GetAttrString (type, "__name__")));
 
-	g_debug ("Registering Python plugin instance: %s", type_name);
+	D("Registering Python plugin instance: %s", type_name);
 	gtype = g_type_module_register_type (module,
 					     TOTEM_TYPE_PLUGIN,
 					     type_name,
