@@ -251,13 +251,12 @@ totem_setup_file_monitoring (Totem *totem)
 
 /* List from xine-lib's demux_sputext.c */
 static const char subtitle_ext[][4] = {
-	"asc",
-	"txt",
 	"sub",
 	"srt",
 	"smi",
 	"ssa",
-	"ass"
+	"ass",
+	"asc"
 };
 
 gboolean
@@ -292,8 +291,9 @@ totem_uri_exists (const char *uri)
 static char *
 totem_uri_get_subtitle_for_uri (const char *uri)
 {
-	char *subtitle, *subtitle_ext_upper;
-	guint len, i, suffix;
+	char *subtitle;
+	guint len, i;
+	gint suffix;
 
 	/* Find the filename suffix delimiter */
 	len = strlen (uri);
@@ -322,6 +322,7 @@ totem_uri_get_subtitle_for_uri (const char *uri)
 
 	/* Search for any files with one of our known subtitle extensions */
 	for (i = 0; i < G_N_ELEMENTS (subtitle_ext) ; i++) {
+		char *subtitle_ext_upper;
 		memcpy (subtitle + suffix + 1, subtitle_ext[i], 3);
 
 		if (totem_uri_exists (subtitle))
@@ -368,9 +369,14 @@ totem_uri_get_subtitle_in_subdir (GFile *file, const char *subdir)
 static char *
 totem_uri_get_cached_subtitle_for_uri (const char *uri)
 {
-	char *basename, *fake_filename, *fake_uri, *ret;
+	char *filename, *basename, *fake_filename, *fake_uri, *ret;
 
-	basename = g_path_get_basename (uri);
+	filename = g_filename_from_uri (uri, NULL, NULL);
+	if (filename == NULL)
+		return NULL;
+
+	basename = g_path_get_basename (filename);
+	g_free (filename);
 	if (basename == NULL || strcmp (basename, ".") == 0) {
 		g_free (basename);
 		return NULL;
@@ -565,6 +571,13 @@ totem_add_subtitle (GtkWindow *parent, const char *path)
 	conf = gconf_client_get_default ();
 	set_folder = TRUE;
 
+	new_path = g_build_filename (g_get_user_cache_dir (),
+				     "totem",
+				     "subtitles",
+				     NULL);
+	gtk_file_chooser_add_shortcut_folder_uri (GTK_FILE_CHOOSER (fs), new_path, NULL);
+	g_free (new_path);
+
 	new_path = gconf_client_get_string (conf, "/apps/totem/open_path", NULL);
 	if (new_path != NULL && *new_path != '\0') {
 		set_folder = gtk_file_chooser_set_current_folder_uri
